# version=0.7
# wget --no-check-certificate https://soft.clang.cn/zsh/clang.zsh-theme -O ~/.oh-my-zsh/custom/themes/clang.zsh-theme && source ~/.zshrc
# theme options: basic clang
local theme="basic"
#local theme="clang"

local ret_status="%(?:%{$fg_bold[green]%}➜:%{$fg_bold[red]%}➜)"
#local ret_status="%(?:%{$fg_bold[green]%}√:%{$fg_bold[red]%}×)"
local user_color='cyan'; [ $UID -eq 0 ] && user_color='green'
local __user=`whoami`

if [ "${theme}"x = "basic"x ]; then
    _fishy_collapsed() {
        echo $(pwd | perl -pe '
        BEGIN {
            binmode STDIN,  ":encoding(UTF-8)";
            binmode STDOUT, ":encoding(UTF-8)";
        }; s|^$ENV{HOME}|~|g; ')
    }
    PROMPT='${ret_status} %{$reset_color%}${__user}@%m:%{$fg[$user_color]%}$(_fishy_collapsed)%{$reset_color%}%(!.#.$)%{$reset_color%} '
    RPS1=''
fi
if [ "${theme}"x = "clang"x ]; then
    _fishy_collapsed_wd() {
    echo $(pwd | perl -pe '
        BEGIN {
            binmode STDIN,  ":encoding(UTF-8)";
            binmode STDOUT, ":encoding(UTF-8)";
        }; s|^$ENV{HOME}|~|g; s|/([^/.])[^/]*(?=/)|/$1|g; s|/\.([^/])[^/]*(?=/)|/.$1|g ')
    }
    os_name=`uname`
    if [ "${os_name}"x = "Darwin"x ]; then
        DISTRO='MacOSX'
    elif grep -Eqi "CentOS" /etc/issue || grep -Eq "CentOS" /etc/*-release; then
        DISTRO='CentOS'
    elif grep -Eqi "Red Hat Enterprise Linux Server" /etc/issue || grep -Eq "Red Hat Enterprise Linux Server" /etc/*-release; then
        DISTRO='RHEL'
    elif grep -Eqi "Aliyun" /etc/issue || grep -Eq "Aliyun" /etc/*-release; then
        DISTRO='Aliyun'
    elif grep -Eqi "Fedora" /etc/issue || grep -Eq "Fedora" /etc/*-release; then
        DISTRO='Fedora'
    elif grep -Eqi "Amazon Linux AMI" /etc/issue || grep -Eq "Amazon Linux AMI" /etc/*-release; then
        DISTRO='Amazon'
    elif grep -Eqi "Debian" /etc/issue || grep -Eq "Debian" /etc/*-release; then
        DISTRO='Debian'
    elif grep -Eqi "Ubuntu" /etc/issue || grep -Eq "Ubuntu" /etc/*-release; then
        DISTRO='Ubuntu'
    elif grep -Eqi "Raspbian" /etc/issue || grep -Eq "Raspbian" /etc/*-release; then
        DISTRO='Raspbian'
    elif grep -Eqi "Deepin" /etc/issue || grep -Eq "Deepin" /etc/*-release; then
        DISTRO='Deepin'
    elif grep -Eqi "Mint" /etc/issue || grep -Eq "Mint" /etc/*-release; then
        DISTRO='Mint'
    else
        DISTRO='unknow'
    fi
    if [ "${DISTRO}"x = "MacOSX"x ]; then
        PRETTY_NAME="$(echo `sw_vers -productName && sw_vers -productVersion`)"
    elif [ "${DISTRO}"x = "unknow"x ]; then
        PRETTY_NAME='unknow'
    elif [ "${DISTRO}"x = "CentOS"x ] && [ ! -e /etc/os-release ]; then
        PRETTY_NAME="$(cat /etc/centos-release)"
    else
        PRETTY_NAME="$(. /etc/os-release && echo "${PRETTY_NAME}")"
    fi
    PROMPT='${ret_status} %{$reset_color%}${__user}@%m:%{$fg[$user_color]%}$(_fishy_collapsed_wd)%{$reset_color%}%{$fg_bold[green]%} $(git_prompt_info)%{$reset_color%}%(!.#.$)%{$reset_color%} '
    RPS1='[${PRETTY_NAME}]'
    ZSH_THEME_GIT_PROMPT_PREFIX="%{$fg_bold[magenta]%}git:(%{$fg[red]%}"
    ZSH_THEME_GIT_PROMPT_SUFFIX="%{$reset_color%} "
    ZSH_THEME_GIT_PROMPT_DIRTY="%{$fg[magenta]%}) %{$fg[yellow]%}✗"
    ZSH_THEME_GIT_PROMPT_CLEAN="%{$fg[magenta]%}) %{$fg[green]%}✓"
fi
#编辑器
export EDITOR=vim
#关于历史纪录的配置 {{{
#历史纪录条目数量
export HISTSIZE=10000
#注销后保存的历史纪录条目数量
export SAVEHIST=10000
#历史纪录文件
export HISTFILE=~/.zsh_history
#以附加的方式写入历史纪录
setopt INC_APPEND_HISTORY
#如果连续输入的命令相同，历史纪录中只保留一个
setopt HIST_IGNORE_DUPS
#为历史纪录中的命令添加时间戳
setopt EXTENDED_HISTORY
#启用 cd 命令的历史纪录，cd -[TAB]进入历史路径
setopt AUTO_PUSHD
#相同的历史路径只保留一个
setopt PUSHD_IGNORE_DUPS
#在命令前添加空格，不将此命令添加到纪录文件中
#setopt HIST_IGNORE_SPACE
#}}}

#kill 命令补全
compdef pkill=kill
compdef pkill=killall
zstyle ':completion:*:*:kill:*' menu yes select
zstyle ':completion:*:*:*:*:processes' force-list always
zstyle ':completion:*:processes' command 'ps -au$USER'

##行编辑高亮模式 {{{
# Ctrl+@ 设置标记，标记和光标点之间为 region
zle_highlight=(region:bg=magenta #选中区域
special:bold      #特殊字符
isearch:underline)#搜索时使用的关键字
#}}}
